@@ -30,26 +30,22 @@ def defup_customers(uuid):
         description: Une erreur interne est survenue
     """
     try:
-        int(uuid)
-    except ValueError:
         customer = lib_customer.Customer(uuid)
-    else:
-        search_customer = [
-            customer for customer in lib_customer.Customer.all()
-            if customer.refnum == uuid
-            ]
-        if search_customer:
-            customer = search_customer.pop()
-        else:  # aucun client n'a été trouvé
-            return not_found(
-                message="Le client {} n'existe pas".format(uuid),
-                code='{}-{}'.format(
-                    SERVICE_CODE,
-                    '4040'
-                    ),
-                service_code=SERVICE_CODE
-                )
+    except ValueError:
+        return not_found(
+            message="Le client {} n'existe pas".format(uuid),
+            code='{}-{}'.format(
+                SERVICE_CODE,
+                '4040'
+                ),
+            service_code=SERVICE_CODE
+            )
     response = customer.defup_from_aiguillier()
+    code = '{}-{}'.format(
+        SERVICE_CODE,
+        response['code']
+        )
+    response['code'] = code
     return jsonify(response)
 
 
@@ -283,7 +279,7 @@ def get_customer_consumption(uuid):
                         ),
                     service_code=SERVICE_CODE
                     )
-        infos = customer.get_cdr_summary(start.date(), stop.date())
+        infos = customer.get_cdr_summary(start.date(), stop.date(), True)
         return jsonify(infos)
 
 # EOF
