@@ -107,6 +107,13 @@ class Product(object):
             params={'product': self.name}
             )
         customers = response['content'].get('customers', [])
+        customers = {
+            customer['name'].lower(): {
+                'product': customer['product'],
+                'refnum': customer['refnum']
+                }
+            for customer in customers
+            }
         existing_customers = {
             customer.name: {
                 'product': customer.product,
@@ -114,25 +121,24 @@ class Product(object):
                 }
             for customer in self.customers
             }
-        if not customers:
-            # on devrait supprimer tous les clients existants
-            # parce qu'Aiguillier nous dit que ce produit n'est
-            # lié à aucun client;
-            # mais pour des raisons de sécurité on ne touche à rien
-            pass
-        else:
-            customers = {
-                customer['name'].lower(): {
-                    'product': customer['product'],
-                    'refnum': customer['refnum']
-                    }
-                for customer in customers
-                }
-            for customer, infos in customers.items():
-                existing_customer = existing_customers.get(customer)
-                if not existing_customer:
-                    # le client n'existe pas dans la base
-                    # on le créé
+        # existing_customers c'est la liste des clients
+        # que l'application classe comme possédant le produit
+        for customer, infos in customers.items():
+            existing_customer = existing_customers.get(customer)
+            if existing_customer:
+                # on vérifie le refnum du client a changé
+                if existing_customer['refnum'] != infos['refnum']:
+                    # on met à jour le refnum
+                    Customer(customer).set_refnum(infos['refnum'])
+            else:
+                # soit le client 'customer' n'existe pas
+                # soit il n'a pas le produit 'self.name'
+                try:
+                    # est-ce-que le client existe dans notre base ?
+                    c = Customer(customer)
+                except ValueError:
+                    # le client n'existe vraiment pas dans la base
+                    # on va le créer
                     url = core.database_url(**FUPDB_CREDENTIALS)
                     with records.Database(url) as db:
                         sql = (
@@ -149,67 +155,32 @@ class Product(object):
                         "Inscription du client {}".format(customer)
                         )
                 else:
-                    # on vérifie si son refnum a changé
-                    if existing_customer['refnum'] != infos['refnum']:
-                        # on met à jour le refnum
-                        url = core.database_url(**FUPDB_CREDENTIALS)
-                        with records.Database(url) as db:
-                            sql = (
-                                "UPDATE customer SET refnum=:refnum "
-                                "WHERE name=:name"
+                    # le client existe déjà dans la base
+                    # donc c'est forcément son produit qui a changé
+                    # on modifie d'abord le refnum au cas où
+                    c = Customer(customer)
+                    # modification du refnum au cas où
+                    c.set_refnum(infos['refnum'])
+                    current_product = c.product
+                    c.set_product(infos['product'])
+                    # on défup de l'ancien s'il faut
+                    customer_status = c.fup_status
+                    for policy_name in current_product.policies:
+                        status = customer_status.get(policy_name)
+                        if status:
+                            status = sorted(
+                                status,
+                                key=lambda x: x['datetime'],
+                                reverse=True
                                 )
-                            db.query(
-                                sql,
-                                refnum=infos['refnum'],
-                                name=customer
-                                )
-                        log_msg = (
-                            "Changement de refnum de {}: {} => {}"
-                            ).format(
-                                customer,
-                                existing_customer['refnum'],
-                                infos['refnum']
-                                )
-                        LOGS.logger.info(log_msg)
-                    # on vérifie si le produit a changé
-                    current_product = existing_customer['product']
-                    if current_product.name != infos['product']:
-                        with records.Database(url) as db:
-                            sql = (
-                                "UPDATE customer SET product=:product "
-                                "WHERE name=:name"
-                                )
-                            db.query(
-                                sql,
-                                refnum=infos['product'],
-                                name=customer
-                                )
-                        log_msg = (
-                            "Changement de produit de {}: {} => {}"
-                            ).format(
-                                customer,
-                                current_product.name,
-                                infos['product']
-                                )
-                        LOGS.logger.info(log_msg)
-                        # on défup de l'ancien produit si nécessaire
-                        customer_status = Customer(customer).fup_status
-                        for policy_name in current_product.policies:
-                            status = customer_status.get(policy_name)
-                            if status:
-                                status = sorted(
-                                    status,
-                                    key=lambda x: x['datetime'],
-                                    reverse=True
+                            if status[0]['status']:
+                                # si le client était fup, il faut le défup
+                                REST_CLIENT.delete(
+                                    '/fup',
+                                    auth=(
+                                        CONFIG['AIGUILLIER']['username'],
+                                        CONFIG['AIGUILLIER']['password']
+                                        ),
+                                    params={'customer': self.name}
                                     )
-                                if status[0]['status']:
-                                    # si le client était fup, il faut le défup
-                                    REST_CLIENT.delete(
-                                        '/fup',
-                                        auth=(
-                                            CONFIG['AIGUILLIER']['username'],
-                                            CONFIG['AIGUILLIER']['password']
-                                            ),
-                                        params={'customer': self.name}
-                                        )
 # EOF
